@@ -1,8 +1,7 @@
-#!/usr/local/bin/python3.9
+#!/usr/local/bin/python3.113
 
 from subprocess import Popen, PIPE
 from sys import argv, stderr, exit
-import os
 import shutil
 
 if (len(argv) != 3):
@@ -11,7 +10,7 @@ if (len(argv) != 3):
 
 with open(argv[1], 'rb') as fsrc:
     subproc = Popen("gnuplot", shell=True, stdin=PIPE)
-    subproc.stdin.write("set terminal pdf\nset output '%s'\n" % argv[2])
+    subproc.stdin.write(b"set terminal pdf\nset output '%s'\n" % argv[2].encode())
     shutil.copyfileobj(fsrc, subproc.stdin)
-    subproc.stdin.write("exit\n")
-    subproc.wait()
+    subproc.stdin.write(b"exit\n")
+    subproc.communicate()
